Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrNotValidSPSSFile = errors.New("Not a valid IBM SPSS Statistics file.")
)
Functions ¶
This section is empty.
Types ¶
type Header ¶
type Header struct {
Fileheader *fileHeader
Variable []*variabler
ValueLabel []*valueLabel
Documents *documents
MachineIntegerInfo *machineIntegerInfo
MachineFloatingPoint *machineFloatingPointInfo
MultipleResponseSetsOld *multipleResponseSets
ExtraProductInfo *extraProductInfo
VariableDisplay *variableDisplay
LongVariableNames *longVariableNames
VeryLongString *veryLongString
ExtendedNCasesInfo *extendedNumberOfCases
DataAttributes *dataAttributes
VariableAttributes *dataAttributes
MultipleResponseSetsNew *multipleResponseSets
CharacterEncoding *characterEncoding
LongStringValueLabels *longStringValueLabels
LongStringMissingValues *longStringMissingValues
DictionaryTermination *dictionaryTermination
ZLibDataHeader *zLibDataHeader
ZLibDataTrailer *zLibDataTrailer
// contains filtered or unexported fields
}
Header contains all the raw IBM SPSS Statistics metadata. It is fairly unstructured
type Reader ¶
type Reader struct {
// contains filtered or unexported fields
}
A Reader reads data from an IBM SPSS Statistics encoded system file
As returned by NewReader blabla
func (*Reader) ChangeEndianess ¶
Change endianess, can be binary.LittleEndian (most common) or binary.BigEndian
func (*Reader) MetaData ¶
MetaData returns Human friendly meta data in form of a list of the Variable struct.
type Variable ¶
type Variable struct {
// Name is the variable name from the variable record or if long from the verylongstring.
Name string
// Label is the variable label.
Label string
// Decimal is the number of decimals in the variable.
Decimal int
// Width is the number of bytes used for the variable.
Width int
// Numeric is a bool if true the variable is a numeric variable.
Numeric bool
// Type is the variable type.
Type int
// List of missing value and long missing value strings.
MissingValues []interface{}
// List of value labels from variable record and LongValueLabels.
ValueLabels []*ValueLabel
// The measurement of the variable, (1) Nominal, (2) Ordinal or (3) Continuous.
Measure int
// contains filtered or unexported fields
}
Variable struct is a collection of useful information from the native spss structs.
Click to show internal directories.
Click to hide internal directories.